/* ============================================================
 * File  : kameraklient.h
 * Author: Tudor Calin <tudor@1xtech.com>
 * Date  : 2004-06-18
 * Description : 
 * 
 * Copyright 2004 by Tudor Calin <tudor@1xtech.com>

 * This program is free software; you can redistribute it
 * and/or modify it under the terms of the GNU General
 * Public License as published by the Free Software Foundation;
 * either version 2, or (at your option)
 * any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * ============================================================ */

#ifndef PLUGIN_KAMERAKLIENT_H
#define PLUGIN_KAMERAKLIENT_H

#include <libkipi/plugin.h>

namespace KIPIKameraKlientPlugin
{
class CameraUI;
class CameraType;
}

class Plugin_KameraKlient : public KIPI::Plugin {
Q_OBJECT
  

public:
    Plugin_KameraKlient(TQObject *parent, const char* name, const TQStringList& args);
    ~Plugin_KameraKlient();
	virtual void setup(TQWidget* widget);
    virtual KIPI::Category category(TDEAction*) const;
    TQString id() const {
		return TQString::fromLatin1("kameraklient");
    }
	TDEAction* mKameraKlientAction;

protected slots:
    void slotActivate();
};

#endif

